@@ -158,9 +158,11 @@ class BaseBoard:
         meta_name = self.meta_factory.get_meta_name(*components)
 
         path_meta = self.construct_path([*components, meta_name])
-        f = self._open_pin_meta(path_meta)
+        f, local = self._open_pin_meta(path_meta)
 
-        meta = self.meta_factory.read_pin_yaml(f, pin_name, selected_version)
+        meta = self.meta_factory.read_pin_yaml(
+            f, pin_name, selected_version, local=local
+        )
 
         return meta
 
@@ -605,7 +607,10 @@ class BaseBoard:
         f = self.fs.open(path)
         self._touch_cache(path)
 
-        return f
+        # optional additional data to put in Meta.local
+        local = {}
+
+        return f, local
 
     def _get_cache_path(self, pin_name, version=None, fname=None):
         version_part = [version] if version is not None else []
@@ -691,8 +696,8 @@ class BoardManual(BaseBoard):
         # note that pins on this board should point to versions, so we use an
         # empty string to mark version (it ultimately is ignored)
         path_meta = self.construct_path([pin_name, "", meta_name])
-        f = self._open_pin_meta(path_meta)
-        meta = self.meta_factory.read_pin_yaml(f, pin_name, VersionRaw(""))
+        f, local = self._open_pin_meta(path_meta)
+        meta = self.meta_factory.read_pin_yaml(f, pin_name, VersionRaw(""), local=local)
 
         # TODO(#59,#83): handle caching, and then re-enable pin_read.
         # self._touch_cache(path_meta)
@@ -866,6 +871,23 @@ class BoardRsConnect(BaseBoard):
             )
         super().pin_versions_prune(*args, **kwargs)
 
+    def _open_pin_meta(self, path):
+        f = self.fs.open(path)
+        self._touch_cache(path)
+
+        # optional additional data to put in Meta.local
+        user_name, content_name, bundle_id = str(path).split("/")[:3]
+        user_guid = self.fs._user_name_cache[user_name]
+        content_guid = self.fs._content_name_cache[(user_guid, content_name)]
+
+        local = {
+            "content_id": content_guid,
+            "version": bundle_id,
+            "url": f"{self.fs.api.server_url}/content/{content_guid}/",
+        }
+
+        return f, local
+
     def validate_pin_name(self, name) -> None:
         # this should be the default behavior, expecting a full pin name.
         # but because the tests use short names, we allow it to be disabled via config
